==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slet kommentar",
    "New comment …" : "Ny kommentar ...",
    "Post" : "Indlæg",
    "Cancel" : "Annullér",
    "[Deleted user]" : "[Slettet user]",
    "Comments" : "Kommentarer",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "More comments …" : "Flere kommentarer...",
    "Save" : "Gem",
    "Allowed characters {count} of {max}" : "Tilladte tegn {count} af {max}",
    "Error occurred while updating comment with id {id}" : "Der opstod fejl under opdatering af kommentar med id {id}",
    "Error occurred while posting comment" : "Der opstod fejl under indsendelse af kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n ulæst kommentar","%n ulæste kommentarer"],
    "Comment" : "Kommentér",
    "You commented" : "Du kommenterede",
    "%1$s commented" : "%1$s kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du blev nævnt i \"{file}”, I en kommentar af en bruger der siden er blevet slettet",
    "{user} mentioned you in a comment on “{file}”" : "{user} nævnte dig i en kommentarer på \"{file}\"",
    "Unknown user" : "Ukendt bruger",
    "A (now) deleted user mentioned you in a comment on “%s”" : "En (nu) slettet bruger nævnte dig i en kommentarer på “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "En (nu) slettet bruger nævnte dig i en kommentarer på \"{file}\"",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nævnte dig i en kommentarer på “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du blev nævnt i \"%s”, I en kommentar af en bruger der er blevet slettet efterfølgende"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slet kommentar",
    "New comment …" : "Ny kommentar ...",
    "Post" : "Indlæg",
    "Cancel" : "Annullér",
    "[Deleted user]" : "[Slettet user]",
    "Comments" : "Kommentarer",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "More comments …" : "Flere kommentarer...",
    "Save" : "Gem",
    "Allowed characters {count} of {max}" : "Tilladte tegn {count} af {max}",
    "Error occurred while updating comment with id {id}" : "Der opstod fejl under opdatering af kommentar med id {id}",
    "Error occurred while posting comment" : "Der opstod fejl under indsendelse af kommentar",
    "_%n unread comment_::_%n unread comments_" : ["%n ulæst kommentar","%n ulæste kommentarer"],
    "Comment" : "Kommentér",
    "You commented" : "Du kommenterede",
    "%1$s commented" : "%1$s kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du blev nævnt i \"{file}”, I en kommentar af en bruger der siden er blevet slettet",
    "{user} mentioned you in a comment on “{file}”" : "{user} nævnte dig i en kommentarer på \"{file}\"",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du blev nævnt i \"%s”, I en kommentar af en bruger der er blevet slettet efterfølgende",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s nævnte dig i en kommentarer på “%2$s”"
},
"nplurals=2; plural=(n != 1);");
